@@ -12,12 +12,12 @@
 #' of_species_list <- of_species_codes()
 #'}
 of_species_codes <- function(foptions = list()) {
-    url <- "http://openfisheries.org/api/landings/species"
+    url <- "http://openfisheries.org/api/landings/species.json"
     species <- GET(url, foptions)
     stop_for_status(species)
     species_data <- content(species)
     species_data <- lapply(species_data, spfillnull)
-    species_data_frame <- data.frame(rbindlist(species_data))
+    species_data_frame <- data.frame(rbindlist(species_data), stringsAsFactors = FALSE)
     species_data_frame
 } 
 
